pub struct Plugboard { /* private fields */ }Expand description
The Enigma Plugboard or Steckerbrett
Implementations
Sourceimpl Plugboard
impl Plugboard
Sourcepub fn new(pairs: &[(Letter, Letter)]) -> Self
pub fn new(pairs: &[(Letter, Letter)]) -> Self
Create a new Plugboard from an array of Letter pairs that represent cable connections
Sourcepub fn remove_cable(&mut self, pair: (Letter, Letter))
pub fn remove_cable(&mut self, pair: (Letter, Letter))
Resets the value of each Letter in the pair.
Equivalent to the logical removal of a cable iff the pair is connected